@@ -25,7 +25,7 @@ until kubectl uncordon "$HOSTNAME"; do sleep 3; done
 # shellcheck disable=SC3028
 cleanup() {
   echo Draining node...
-  kubectl drain "$HOSTNAME" --force --delete-emptydir-data
+  kubectl drain "$HOSTNAME" --force --delete-emptydir-data --ignore-daemonsets --disable-eviction
   echo Sending SIGTERM to k3s...
   kill -15 $k3s_pid
   echo Waiting for k3s to close...
